from setuptools import setup, find_packages


VERSION = '1.0.0'

setup(
    name='shiqingTools',  # package name
    version=VERSION,  # package version
    author="buyizhiyou",
    author_email="2557040812@qq.com",
    license="MIT",
    url='https://github.com/buyizhiyou',
    description='some personal tools',  # package description
    packages=find_packages('shiqingTools'),
    package_dir = {'':'shiqingTools'},
    include_package_data = True,
    zip_safe=False,
)



from argparse import ArgumentParser

parse = ArgumentParser()
parse.add_argument("-i", "--input", default=r'input.py', type=str)
parse.add_argument("-o", "--output", default=r'output.txt', type=str)

args=parse.parse_args()


with open(args.input,"r") as f:
    lines = f.readlines()
    lines = ["\""+line.strip("\n")+"\""+",\n"  for line in lines if line.strip()!=""]

with open(args.output,"w") as g:
    g.writelines(lines)

